<?php
//  TABLE OF CONTENTS

//  Localization Initialize
//  Archive Pagination
//	Dynamic Titles
//  Dynamic Body Classes
//  Get first image in a post
//  Comment output
//  Comment microid
//  List Categories with Descriptions
//  Support for 2.9 Canonical Post Thumbnail
//  Add Justin Tadlock's Breadcrumb plugin
//  Widgets Areas and Custom Widgets
//  
//  ** Added in 1.0.7 **
//  Visual editor styles http://azaozz.wordpress.com/2010/01/02/can-themes-style-the-visual-editor/


/* Localization Initialize
 * --------------------------------------------------------------------------------------- */
load_theme_textdomain('pico');

/* Archive Pagination
 * --------------------------------------------------------------------------------------- */
function my_post_limit($limit) {
	global $paged, $myOffset, $postsperpage;
	if(empty($paged)) {
		$paged = 1;
	}
	$pgstrt = ((intval($paged) -1) * $postsperpage) + $myOffset . ', ';
	$limit = 'LIMIT '.$pgstrt.$postsperpage;
	return $limit;
}

/* Dynamic Titles 
 * --------------------------------------------------------------------------------------- */
function dynamictitles() {
	
	if ( is_single() ) {
      wp_title('');
      echo (' | ');
      bloginfo('name');
 
} else if ( is_page() || is_paged() ) {
      bloginfo('name');
      wp_title('|');
 
} else if ( is_author() ) {
      bloginfo('name');
      wp_title(' | '.__('Author','pico').'');	  
	  
} else if ( is_category() ) {
      bloginfo('name');
      wp_title(' | '.__('Archive for','pico').'');
      ('');

} else if ( is_tag() ) {
      bloginfo('name');
      echo (' | '.__('Tag archive for','pico').'');
      wp_title('');

} else if ( is_archive() ) {
      bloginfo('name');
      echo (' | '.__('Archive for','pico').'');
      wp_title('');

} else if ( is_search() ) {
      bloginfo('name');
      echo (' | '.__('Search Results','pico').'');
 
} else if ( is_404() ) {
      bloginfo('name');
      echo (' | '.__('404 Error (Page Not Found)','pico').'');
	  
} else if ( is_home() ) {
      bloginfo('name');
      echo (' | ');
      bloginfo('description');
 
} else {
      bloginfo('name');
      echo (' | ');
      echo (''.$blog_longd.'');
  }
}

/* Dynamic Body Classes, courtesy of Thematic and Sandbox
 * --------------------------------------------------------------------------------------- */
function bodystyle( $print = true ) {
	global $wp_query, $current_user;
	
	// Generic semantic classes for what type of content is displayed
	is_front_page()  ? $c[] = 'home'       : null; // For the front page, if set
	is_home()        ? $c[] = 'blog'       : null; // For the blog posts page, if set
	is_archive()     ? $c[] = 'archive'    : null;
	is_date()        ? $c[] = 'by-date'    : null;
	is_search()      ? $c[] = 'search'     : null;
	is_paged()       ? $c[] = 'paged'      : null;
	is_attachment()  ? $c[] = 'attachment' : null;
	is_404()         ? $c[] = 'four04'     : null; // CSS does not allow a digit as first character

	// Special classes for BODY element when a single post
	if ( is_single() ) {
		$postID = $wp_query->post->ID;
		the_post();

		// Adds 'single' class and class with the post ID
		$c[] = 'single postid-' . $postID;

		// Adds classes for the month, day, and hour when the post was published
		if ( isset( $wp_query->post->post_date ) )
			thematic_date_classes( mysql2date( 'U', $wp_query->post->post_date ), $c, '' );

		// Adds category classes for each category on single posts
		if ( $cats = get_the_category() )
			foreach ( $cats as $cat )
				$c[] = 'category-' . $cat->slug;

		// Adds tag classes for each tags on single posts
		if ( $tags = get_the_tags() )
			foreach ( $tags as $tag )
				$c[] = 'tag-' . $tag->slug;

		// Adds MIME-specific classes for attachments
		if ( is_attachment() ) {
			$mime_type = get_post_mime_type();
			$mime_prefix = array( 'application/', 'image/', 'text/', 'audio/', 'video/', 'music/' );
				$c[] = 'attachmentid-' . $postID . ' attachment-' . str_replace( $mime_prefix, "", "$mime_type" );
		}

		// Adds author class for the post author
		$c[] = 'author-' . sanitize_title_with_dashes(strtolower(get_the_author_login()));
		rewind_posts();
	}

	// Author name classes for BODY on author archives
	elseif ( is_author() ) {
		$author = $wp_query->get_queried_object();
		$c[] = 'author';
		$c[] = 'author-' . $author->user_nicename;
	}

	// Category name classes for BODY on category archvies
	elseif ( is_category() ) {
		$cat = $wp_query->get_queried_object();
		$c[] = 'category';
		$c[] = 'category-' . $cat->slug;
	}

	// Tag name classes for BODY on tag archives
	elseif ( is_tag() ) {
		$tags = $wp_query->get_queried_object();
		$c[] = 'tag';
		$c[] = 'tag-' . $tags->slug;
	}

	// Page author for BODY on 'pages'
	elseif ( is_page() ) {
		$pageID = $wp_query->post->ID;
		$page_children = wp_list_pages("child_of=$pageID&echo=0");
		the_post();
		$c[] = 'page pageid-' . $pageID;
		$c[] = 'page-author-' . sanitize_title_with_dashes(strtolower(get_the_author('login')));
		// Checks to see if the page has children and/or is a child page; props to Adam
		if ( $page_children )
			$c[] = 'page-parent';
		if ( $wp_query->post->post_parent )
			$c[] = 'page-child parent-pageid-' . $wp_query->post->post_parent;
		if ( is_page_template() ) // Hat tip to Ian, themeshaper.com
			$c[] = 'page-template page-template-' . str_replace( '.php', '-php', get_post_meta( $pageID, '_wp_page_template', true ) );
		rewind_posts();
	}

	// Search classes for results or no results
	elseif ( is_search() ) {
		the_post();
		if ( have_posts() ) {
			$c[] = 'search-results';
		} else {
			$c[] = 'search-no-results';
		}
		rewind_posts();
	}

	// Paged classes; for 'page X' classes of index, single, etc.
	if ( ( ( $page = $wp_query->get('paged') ) || ( $page = $wp_query->get('page') ) ) && $page > 1 ) {
		$c[] = 'paged-' . $page;
		if ( is_single() ) {
			$c[] = 'single-paged-' . $page;
		} elseif ( is_page() ) {
			$c[] = 'page-paged-' . $page;
		} elseif ( is_category() ) {
			$c[] = 'category-paged-' . $page;
		} elseif ( is_tag() ) {
			$c[] = 'tag-paged-' . $page;
		} elseif ( is_date() ) {
			$c[] = 'date-paged-' . $page;
		} elseif ( is_author() ) {
			$c[] = 'author-paged-' . $page;
		} elseif ( is_search() ) {
			$c[] = 'search-paged-' . $page;
		}
	}

	// Separates classes with a single space, collates classes for BODY
	$c = join( ' ', apply_filters( 'body_class',  $c ) ); // Available filter: body_class

	// And tada!
	return $print ? print($c) : $c;
}

// Generates time- and date-based classes for BODY, post DIVs, and comment LIs; relative to GMT (UTC)
function thematic_date_classes( $t, &$c, $p = '' ) {
}

function post_strip($where) {
	global $myPosts, $wpdb;
	$where .= " AND $wpdb->posts.ID not in($myPosts) "; 
	return $where;
}


/* Get first image in a post
 * ---------------------------------------------------------------------------------------
 * GET-POST-IMAGE script by Tim McDaniels, written for the Mimbo theme.
 * Modified to return false when there's no image.
 * --------------------------------------------------------------------------------------- */ 
function get_post_image ($post_id=0, $width=0, $height=0, $img_script='') {
	global $wpdb;
	if($post_id > 0) {

		 // select the post content from the db

		 $sql = 'SELECT post_content FROM ' . $wpdb->posts . ' WHERE id = ' . $wpdb->escape($post_id);
		 $row = $wpdb->get_row($sql);
		 $the_content = $row->post_content;
		 if(strlen($the_content)) {

			  // use regex to find the src of the image

			preg_match("/<img src\=('|\")(.*)('|\") .*( |)\/>/", $the_content, $matches);
			if(!$matches) {
				preg_match("/<img class\=\".*\" title\=\".*\" src\=('|\")(.*)('|\") .*( |)\/>/U", $the_content, $matches);
			}
			$the_image = '';
			$the_image_src = $matches[2];
			$frags = preg_split("/(\"|')/", $the_image_src);
			if(count($frags)) {
				$the_image_src = $frags[0];
			}

			  // if src found, then create a new img tag

			  if(strlen($the_image_src)) {
				   if(strlen($img_script)) {

					    // if the src starts with http/https, then strip out server name

					    if(preg_match("/^(http(|s):\/\/)/", $the_image_src)) {
						     $the_image_src = preg_replace("/^(http(|s):\/\/)/", '', $the_image_src);
						     $frags = split("\/", $the_image_src);
						     array_shift($frags);
						     $the_image_src = '/' . join("/", $frags);
					    }
					    $the_image = '<img alt="" src="' . $img_script . $the_image_src . '" />';
				   }
				   else {
					    $the_image = '<img alt="" src="' . $the_image_src . '" width="' . $width . '" height="' . $height . '" />';
				   }
			  }
        
        // if there's no image
        else
          return false;
          
			  return $the_image;
		 }
	}
}


/* Callback functions for comment output
 * --------------------------------------------------------------------------------------- */
function mytheme_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
     <div id="comment-<?php comment_ID(); ?>">
      <div class="comment-author vcard clearfloat">
         <?php echo get_avatar($comment,$size='48',$default='<path_to_url>' ); ?>
			
			<div class="commentmetadata">
        <?php printf(__('<cite class="fn">%s</cite>','pico'), get_comment_author_link()) ?>
		 
		 
	 <div class="comment-date"><a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">
	  <?php printf(__('%1$s &bull; %2$s'), get_comment_date(),  get_comment_time()) ?></a>
	  <?php edit_comment_link(__('(Edit)','pico')) ?>
	  </div>
	  </div>
	  
      </div><!--END COMMENT-AUTHOR-->
	  
      <?php if ($comment->comment_approved == '0') : ?>
         <em><?php _e('Your comment is awaiting moderation.','pico') ?></em>
         <br />
      <?php endif; ?>

      <?php comment_text() ?>

      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
     </div>
<?php
        }
		
		
/* Add microid to comments
 * --------------------------------------------------------------------------------------- */
function comment_add_microid($classes) {
	$c_email=get_comment_author_email();
	$c_url=get_comment_author_url();
	if (!empty($c_email) && !empty($c_url)) {
		$microid = 'microid-mailto+http:sha1:' . sha1(sha1('mailto:'.$c_email).sha1($c_url));
		$classes[] = $microid;
	}
	return $classes;	
}
add_filter('comment_class','comment_add_microid');

/* List Categories with Descriptions
 * ---------------------------------------------------------------------------------------
 * Create a modified output of wp_list_categories where the categories description
 * is added inside a <span> within the link like so:
 * <li>
 *   <a href="#" title="Category Description">Category Name
 *     <span>Category Description</span>
 *   </a>
 * </li>
 * --------------------------------------------------------------------------------------- */
function list_cats_with_desc() {
  $default_text = "Category";
  $base = wp_list_categories('title_li=&echo=0&exclude_tree=32');
  
  // wp_list_categories adds a "cat-item-[category_id]" class to the <li> so let's make use of that!
  // Shouldn't really use regexp to parse HTML, but oh well.
  // (for the curious, here's why: http://stackoverflow.com/questions/1732348/regex-match-open-tags-except-xhtml-self-contained-tags/1732454#1732454 )

  $get_cat_id = '/cat-item-[0-9]+/';
  preg_match_all($get_cat_id, $base, $cat_id); 

  // Let's prepare our category descriptions to be injected.
  // Format will be <a>category-name<span>category-desc</span></a>
  $inject_desc = array();

  $i = 0;
  foreach($cat_id[0] as $id) {
    $id = trim($id,'cat-item-');
    $id = trim($id,'"');
    
    $desc = trim(strip_tags(category_description($id)),"\n");   // For some reason, category_description returns the
                                                                // description wrapped in an unwanted <p> tag which
                                                                // we remove with strip_tags. It also adds a newline
                                                                // which we promptly trim out.
    if($desc=="") $desc = $default_text;
    
    $inject_desc[$i] = '<span class="cat-desc">' . $desc . '</span></a>';
    
    $i++;
  }
  
  // Now we inject our descriptions into $output.
  $base_arr = explode("\n", $base);
  
  $base_i = 0;
  foreach($inject_desc as $desc) {
    
    // We check whether there's an occurence of </a>
    while(strpos($base_arr[$base_i], "</a>") === false) {    
      $base_i++;
    }
    
    // If we found one, then we inject our description <span>
    $base_arr[$base_i] = str_replace("</a>", $desc, $base_arr[$base_i]);

    $base_i++;    
  }
  
  //print_r($inject_desc);  
  //print_r($base_arr);  

  $base = implode("\n", $base_arr);
  echo $base;
}

/* Support for 2.9 Canonical Post Thumbnail
 * --------------------------------------------------------------------------------------- */
if ( function_exists( 'add_theme_support' ) )
  add_theme_support( 'post-thumbnails' );

/* Add Justin Tadlock's Breadcrumb plugin
 * --------------------------------------------------------------------------------------- */
include (TEMPLATEPATH . '/breadcrumb-trail.php');


/* Widgets Areas and Custom Widgets
 * --------------------------------------------------------------------------------------- */

if ( function_exists('register_sidebar') ) {

    register_sidebar(array(
      'name' => 'Pico Spotlight',
      'id' => 'pico-spotlight',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Widget area with the most prominence, located topmost on the right sidebar area, visually strong with special background color. Good for important info, ads, call-to-action, etc.', 'pico')
    ));
    
    register_sidebar(array(
      'name' => 'Pico Right Sidebar',
      'id' => 'pico-right-sidebar',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Right sidebar, below the Spotlight. Shows up on every page.', 'pico')      
    ));
    
    register_sidebar(array(
      'name' => 'Pico Left Sidebar',
      'id' => 'pico-left-sidebar',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Left sidebar, does not show up on single Post / Page view.', 'pico')      
    ));

    register_sidebar(array(
      'name' => 'Pico Index Top',
      'id' => 'pico-index-top',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Located before the Lead Post on home page.', 'pico')      
    ));  
    
    register_sidebar(array(
      'name' => 'Pico Index Insert',
      'id' => 'pico-index-insert',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Located after the lead Post on home page, before the Recent Posts.', 'pico')            
    ));        
    
    register_sidebar(array(
      'name' => 'Pico Index Bottom',
      'id' => 'pico-index-bottom',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Located after Older Posts on home page.', 'pico')            
    ));    

    register_sidebar(array(
      'name' => 'Pico Footer First',
      'id' => 'pico-footer-1st',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Leftmost column on footer.', 'pico')            
    ));  

    register_sidebar(array(
      'name' => 'Pico Footer Second',
      'id' => 'pico-footer-2nd',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Second to left column on footer.', 'pico')                  
    ));  

    register_sidebar(array(
      'name' => 'Pico Footer Third',
      'id' => 'pico-footer-3rd',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Second to right column on footer.', 'pico')      
    ));  

    register_sidebar(array(
      'name' => 'Pico Footer Fourth',
      'id' => 'pico-footer-4th',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Rightmost column on footer.', 'pico')      
    ));

    /* Added in version 1.0.7 */
    register_sidebar(array(
      'name' => 'Pico Single Bottom',
      'id' => 'pico-single-bottom',
      'before_widget' => '<div class="widget clearfloat">',
      'after_widget' => '</div>',
      'before_title' => '<h3 class="widget_title">',
      'after_title' => '</h3>',
      'description' => __('Area between the Post/Page content and Comments area.', 'pico')      
    ));    
  }

/* Custom Widget: Featured Categories 
 * Original code by Darren Hoyt.
 */

class pico_widget_featured_cats extends WP_Widget {

	function pico_widget_featured_cats() {
		parent::WP_Widget(false, 'Pico Featured Category');
	}

	function widget($args, $instance) {
  
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Featured Categories') : $instance['title']);
		if ( !$number = (int) $instance['number'] )
			$number = 5;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;
      
    echo $args['before_widget'] . $args['before_title'] . $title . $args['after_title'];
?>
  <div id="featured_cats_widget">
<?php
    $display_categories = $instance['cats'];
    foreach ($display_categories as $category) { 
    $showposts = $number;
    query_posts("showposts=$showposts&cat=$category");
    ?>

    <h5><a href="<?php echo get_category_link($category);?>"><?php single_cat_title(); ?></a></h5>

      <ul>
      <?php while (have_posts()) : the_post(); ?>
      <li class="clearfloat">
        <a href="<?php the_permalink() ?>" rel="bookmark" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a>
        <p class="date"><?php the_time('j F Y'); ?></p>
      </li>
      <?php endwhile; ?>
      </ul>
    
    <?php } ?>
  </div> <!-- #featured_cats_widget -->

<?php
    echo $args['after_widget'];
	}

	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	function form($instance) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 5;    

    // print_r(array_values($instance['cats'])); /* uncomment this to debug */
 ?>
  <p>
    <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?>
    <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
  </label>
  </p>
  <p>
      <p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of Posts per Category:'); ?></label>
      <input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><br />
      <small><?php _e('(at most 15)'); ?></small></p>
  </p>
  <p>
    <label for="<?php echo $this->get_field_id('cats'); ?>[]"><?php _e('Categories:'); ?>
    <select id="<?php echo $this->get_field_id('cats'); ?>" name="<?php echo $this->get_field_name('cats'); ?>[]" multiple="multiple" style="width:230px;height:130px;">
    <?php 
      $kittens = get_categories();
      foreach ($kittens as $cat) {
        if (in_array($cat->term_id, $instance['cats'])) {
          echo '<option value="'.$cat->term_id.'" selected="selected">'.$cat->name.'</option>';	  
        } 
        else {
          echo '<option value="'.$cat->term_id.'">'.$cat->name.'</option>';	 
        }
      }
    ?>
    </select>
  </p>
<?php
  }
} 
register_widget('pico_widget_featured_cats');

add_filter('mce_css', 'my_editor_style');
function my_editor_style($url) {

  if ( !empty($url) )
    $url .= ',';

  // Change the path here if using sub-directory
  $url .= trailingslashit( get_stylesheet_directory_uri() ) . 'editor-style.css';

  return $url;
}
?>